commit - a80b99e21fc857df67ec90b2b3d86ea3b87de4b1
commit + 388e7b970816daf27b983c96507e5a68ddf63ed7
blob - c43bfa8cdc6ace8ebc66ca3bc06c640d48d08ecf
blob + c6eadc64e2347a901f38d067acfc2afa71a423a9
--- gotsysd/gotsysd.h
+++ gotsysd/gotsysd.h
/* Followed by name_len bytes. */
- /* Followed by messages containining authorized keys. */
+ /* Followed by messages containing authorized keys. */
};
/*
blob - fac1c4f570df4862991d4f658c5a3c11a704dc7b
blob + d7d8cbbab8b04fedea529e4a9f117b9ed08ff3c0
--- gotsysd/libexec/gotsys-apply-conf/gotsys-apply-conf.c
+++ gotsysd/libexec/gotsys-apply-conf/gotsys-apply-conf.c
int i;
const int maxwait = 10;
- /* TOOD: gotd_fetch flags from rc.conf.local and pass them in. */
+ /* TODO: gotd_fetch flags from rc.conf.local and pass them in. */
err = start_child(&pid, GOTSYSD_PATH_PROG_GOTD, NULL, NULL);
if (err)
return err;
blob - eac2e130716a0c60236d2758d09f5b859e2fac24
blob + 2129c06e56a96b8817ac114cbe0ef6fe73bad07e
--- lib/gotsys_conf.c
+++ lib/gotsys_conf.c
for (i = 0; i < len; i++) {
/*
* On non-OpenBSD systems, isalnum(3) can suffer from
- * locale-dependent-behaviour syndrom.
+ * locale-dependent-behaviour syndrome.
* Prevent non-ASCII characters in a portable way.
*/
if (name[i] & 0x80)
for (i = 0; i < len; i++) {
/*
* On non-OpenBSD systems, isalnum(3) can suffer from
- * locale-dependent-behaviour syndrom.
+ * locale-dependent-behaviour syndrome.
* Prevent non-ASCII characters in a portable way.
*/
if (comment[i] & 0x80)
blob - 62a18caba95b0b7be549626721fce091f75e7b31
blob + e31173ba47a03503c2f655a30d71c826508b06c2
--- regress/gotsysd/test_gotsysd.sh
+++ regress/gotsysd/test_gotsysd.sh
fi
# The user should have a home directory and ~/.ssh.
- # TODO: stat ~ and ~/.ssh, then verify owership and permissions.
+ # TODO: stat ~ and ~/.ssh, then verify ownership and permissions.
ssh -q -i ${GOTSYSD_SSH_KEY} \
root@${VMIP} ls /home/${GOTSYSD_DEV_USER} \
> $testroot/stdout
test_user_anonymous() {
local testroot=`test_init user_anonymous 1`
# An attempt to grant write permissions to anonymus is an error.
cat > ${testroot}/bad-gotsys.conf <<EOF
repository "gotsys" {
permit rw anonymous
> $testroot/stdout 2> $testroot/stderr
ret=$?
if [ $ret -eq 0 ]; then
- echo "gotsys check suceeded unexpectedly" >&2
+ echo "gotsys check succeeded unexpectedly" >&2
test_done "$testroot" 1
return 1
fi
permit ro anonymous
}
EOF
- (cd ${testroot}/wt && got commit -m "add anonymus user" >/dev/null)
+ (cd ${testroot}/wt && got commit -m "add anonymous user" >/dev/null)
local commit_id=`git_show_head $testroot/${GOTSYS_REPO}`
got send -q -i ${GOTSYSD_SSH_KEY} -r ${testroot}/${GOTSYS_REPO}
> $testroot/stdout 2> $testroot/stderr
ret=$?
if [ $ret -eq 0 ]; then
- echo "gotsys check suceeded unexpectedly" >&2
+ echo "gotsys check succeeded unexpectedly" >&2
test_done "$testroot" 1
return 1
fi
@@
test_user_anonymous() {
local testroot=`test_init user_anonymous 1`
- # An attempt to grant write permissions to anonymus is an error.
+ # An attempt to grant write permissions to anonymous is an error.
cat > ${testroot}/bad-gotsys.conf <<EOF
repository "gotsys" {